import java.util.*;

public class bomas_AN {
  static class Circle {
    final long x, y, r, q;
    boolean isSelected = false;
    int value = 0;
    Circle parent = null;
    ArrayList<Circle> children = new ArrayList<Circle>();

    public Circle(long x, long y, long r, long q) {
      this.x = x;
      this.y = y;
      this.r = r;
      this.q = q;
    }

    public void addChild(Circle c) {
      c.parent = this;
      children.add(c);
    }
  }

  static class Event implements Comparable<Event> {
    final Circle c;
    final int sgn;
    final long x;

    public Event(Circle c, int sgn) {
      this.c = c;
      this.sgn = sgn;
      this.x = c.x + c.r * sgn;
    }

    @Override
    public int compareTo(Event o) {
      return Long.compare(this.x, o.x);
    }
  }

  static long curX = -10000000;
  static class Boundary implements Comparable<Boundary> {
    final Circle c;
    final int sgn;

    public Boundary(Circle c, int sgn) {
      this.c = c;
      this.sgn = sgn;
    }

    double eval() {
      return c.y + sgn * Math.sqrt(c.r * c.r - (c.x - curX) * (c.x - curX));
    }

    @Override
    public int compareTo(Boundary o) {
      if (this.c == o.c) return sgn;
      return Double.compare(this.eval(), o.eval());
    }

    @Override
    public boolean equals(Object other) {
      if (!(other instanceof Boundary)) return false;
      Boundary o = (Boundary) other;
      return this.c == o.c && this.sgn == o.sgn;
    }
  }

  public static void main(String[] args) {
    Scanner s = new Scanner(System.in);
    int n = s.nextInt(), m = s.nextInt();

    Circle[] circles = new Circle[n + m];
    for (int i = 0; i < n; i++) {
      circles[i] = new Circle(s.nextLong(), s.nextLong(), s.nextLong(), -1);
    }
    for (int i = 0; i < m; i++) {
      circles[n + i] = new Circle(s.nextLong(), s.nextLong(), s.nextLong(), i);
    }

    Event[] events = new Event[2 * (n + m)];
    for (int i = 0; i < n + m; i++) {
      events[2 * i] = new Event(circles[i], 1);
      events[2 * i + 1] = new Event(circles[i], -1);
    }
    Arrays.sort(events);

    TreeSet<Boundary> sweepLine = new TreeSet<Boundary>();
    for (Event e : events) {
      curX = e.x;
      if (e.sgn == 1) { // close
        sweepLine.remove(new Boundary(e.c, 1));
        sweepLine.remove(new Boundary(e.c, -1));
      } else { // open
        Boundary upper = new Boundary(e.c, 1);
        Boundary higher = sweepLine.higher(upper);
        if (higher != null) {
          if (higher.sgn == 1) {
            higher.c.addChild(e.c);
          } else if (higher.c.parent != null) {
            higher.c.parent.addChild(e.c);
          }
        }
        Boundary lower = new Boundary(e.c, -1);
        sweepLine.add(upper);
        sweepLine.add(lower);
      }
    }

    Arrays.sort(circles, (Circle o1, Circle o2) -> Long.compare(o1.r, o2.r));
    for (Circle c : circles) {
      boolean hasSelectedChild = c.children.stream().anyMatch((circle) -> circle.isSelected);
      int childrenSum = c.children.stream().mapToInt((circle) -> circle.value).sum();
      if (c.q >= 0) {
        c.isSelected = hasSelectedChild;
        c.value = childrenSum;
      } else {
        c.isSelected = !hasSelectedChild;
        c.value = childrenSum + (hasSelectedChild ? 0 : 1);
      }
    }

    Arrays.sort(circles, (Circle o1, Circle o2) -> Long.compare(o1.q, o2.q));
    for (Circle c : circles) if (c.q >= 0) System.out.println(c.value + (c.isSelected ? 0 : 1));
  }
}
