
import java.util.*;
import java.io.*;

public class bomas_font
{
   public static void main(String[] args) throws Exception
   {
      PrintWriter out = new PrintWriter(System.out);
      new bomas_font(new FastScanner(System.in), out);
      out.close();
   }

   public bomas_font(FastScanner in, PrintWriter out)
   {
      int ptr = 0;
      int N = in.nextInt();
      int Q = in.nextInt();
      Event[] events = new Event[2*(N+Q)];
      Circle[] allCircles = new Circle[N+Q];
      for (int i=0; i<N+Q; i++)
      {
         allCircles[i] = new Circle();
         int x = in.nextInt();
         int y = in.nextInt();
         int r = in.nextInt();
         allCircles[i].x = x;
         allCircles[i].y = y;
         allCircles[i].r = r;
         allCircles[i].id = i;

         Envelope upper = new Envelope();
         upper.c = allCircles[i];
         upper.type = 0;
         Envelope lower = new Envelope();
         lower.c = allCircles[i];
         upper.type = 1;

         Event e = new Event();
         e.type = 0;
         e.x = x - r;
         e.upper = upper;
         e.lower = lower;
         events[ptr++] = e;

         e = new Event();
         e.type = 1;
         e.x = x + r;
         e.upper = upper;
         e.lower = lower;
         events[ptr++] = e;
      }

      TreeSet<Envelope> hull = new TreeSet<>();
      Arrays.sort(events);
      for (Event e : events)
      {
         Envelope.time = e.x;
         Circle c = e.upper.c;

         if (e.type == 0)
         {
            // Find a parent or sibling 
            Envelope trace = hull.higher(e.upper);
            if (trace != null)
            {
               if (trace.type == 0)
                  c.parent = trace.c;
               else
                  c.sibling = trace.c;
            }
            hull.add(e.upper);
            hull.add(e.lower);
         }
         else
         {
            hull.remove(e.upper);
            hull.remove(e.lower);
         }
      }

      // Resolve all the parents
      ArrayDeque<Circle> stk = new ArrayDeque<>();
      for (Circle c : allCircles)
      {
         if (c.sibling != null)
         {
            Circle cc = c;
            while (cc.sibling != null)
            {
               stk.push(cc);
               cc = cc.sibling;
            }
            while (stk.size() > 0)
            {
               Circle ccc = stk.pop();
               ccc.parent = cc.parent;
               ccc.sibling = null;
            }
         }
      }
      Arrays.sort(allCircles);

      int[] results = new int[Q];
      for (Circle c : allCircles)
      {
         if (c.parent != null)
            c.parent.children.add(c);
      
         /*
         for (Circle nxt : c.children)
         {
            out.printf("%s -> %s%n", c, nxt);
         }*/
          
         if (c.id >= N)
         {
            for (Circle nxt : c.children)
            {
               c.sumTake += nxt.sumTake;
               c.sumNoTake += nxt.sumNoTake;

               c.sumTake += nxt.noTake;
               c.sumNoTake += nxt.best;
            }
            
            results[c.id - N] = Math.max(c.sumTake+1, c.sumNoTake);
         }
         else
         {
            int sumTake = 1;
            int sumNoTake = 0;
            for (Circle nxt : c.children)
            {
               sumNoTake += nxt.best + nxt.sumNoTake;
               sumTake += nxt.noTake + nxt.sumTake;
            }
            c.best = Math.max(sumTake, sumNoTake);
            c.noTake = sumNoTake;
            //out.printf("            %s : %d %d : %d %d%n", c, c.best, c.noTake, sumTake, sumNoTake);
         }
      }

      for (int r : results)
         out.println(r);
   }
}

class Envelope implements Comparable<Envelope>
{
   static double time;

   int type; // 0 - upper, 1 - lower
   Circle c;

   double getY(double x)
   {
      double dx = x - c.x;
      double dy = Math.sqrt(c.r * 1.0 * c.r - dx * dx);
      if (type == 0)
         return c.y + dy;
      return c.y - dy;
   }

   public int compareTo(Envelope rhs)
   {
      double y1 = getY(time);
      double y2 = rhs.getY(time);

      if (Math.abs(y1-y2) < 1e-9)
         return rhs.type - type;
      return Double.compare(y1, y2);
   }
}

class Circle implements Comparable<Circle>
{
   int x, y, r, id, best, noTake;

   int sumTake, sumNoTake;

   Circle sibling;
   Circle parent;
   ArrayList<Circle> children;

   public Circle()
   {
      children = new ArrayList<>();
   }

   public int compareTo(Circle rhs)
   {
      return Integer.compare(r, rhs.r);
   }
   
   public String toString()
   {
      return String.format("%d %d %d", x, y, r);
   }
}

class Event implements Comparable<Event>
{
   int type; // 0 - start, 1 - end
   int x;

   Envelope upper;
   Envelope lower;

   public int compareTo(Event rhs)
   {
      return Integer.compare(x, rhs.x);
   }
}

class FastScanner
{
   private InputStream stream;
   private byte[] buf = new byte[1024];
   private int curChar;
   private int numChars;
    
   public FastScanner(InputStream stream)
   {
      this.stream = stream;
   }
    
   int read()
   {
      if (numChars == -1)
         throw new InputMismatchException();
      if (curChar >= numChars)
      {
         curChar = 0;
         try
         {
            numChars = stream.read(buf);
         } 
         catch (IOException e) 
         {
            throw new InputMismatchException();
         }
         
         if (numChars <= 0)
            return -1;
      }
      return buf[curChar++];
   }
    
   boolean isSpaceChar(int c)
   {
      return c==' '||c=='\n'||c=='\r'||c=='\t'||c==-1;
   }
   
   boolean isEndline(int c)
   {
      return c=='\n'||c=='\r'||c==-1;
   }
   
   int nextInt()
   {
      return Integer.parseInt(next());
   }
   
   long nextLong()
   {
      return Long.parseLong(next());
   }
   
   double nextDouble()
   {
      return Double.parseDouble(next());
   }
   
   String next()
   {
      int c = read();
      while (isSpaceChar(c))
         c = read();
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isSpaceChar(c));
      return res.toString();
   }
   
   String nextLine()
   {
      int c = read();
      while (isEndline(c))
         c = read();
      
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isEndline(c));
      return res.toString();
   }
}
