// O(n^2) find parent circle.
// Check circle in increasing (radius, x, y, index)
// Cheese: Only enumerates the IT_LIMIT smallest and largest circles.

#include <iostream>
#include <cstdio>
#include <cmath>
#include <cstring>
#include <algorithm>
#include <string>
#include <vector>
#include <stack>
#include <queue>
#include <set>
#include <map>
#include <sstream>
#include <complex>
#include <ctime>
#include <cassert>
#include <functional>

using namespace std;

typedef long long ll;
typedef vector<int> VI;
typedef pair<int,int> PII;

#define REP(i,s,t) for(int i=(s);i<(t);i++)
#define FILL(x,v) memset(x,v,sizeof(x))

const int INF = (int)1E9;
#define MAXN 200005
#define IT_LIMIT 2000

int Y;
int n, x[MAXN], y[MAXN], r[MAXN], par[MAXN], dp[MAXN][2];
VI child[MAXN];
struct Arc {
  int id, side;
  Arc(int _id, int _side): id(_id), side(_side) {}
  bool operator < (const Arc &ano) const {
    return PII(x[id] + side * r[id], r[id]) < PII(x[ano.id] + side * r[id], r[ano.id]);
  }
};

bool contains(int i, int j) {
  if (r[i] <= r[j]) return false;
  if (x[i] - r[i] >= x[j] + r[j] || x[i] + r[i] <= x[j] - r[j]) return false;
  if (y[i] - r[i] >= y[j] + r[j] || y[i] + r[i] <= y[j] - r[j]) return false;
  return (ll)(x[i] - x[j]) * (x[i] - x[j]) + (ll)(y[i] - y[j]) * (y[i] - y[j]) <= (ll)(r[i] - r[j]) * (r[i] - r[j]);
}

void update(int &p, int id) {
  if (p == -1 || r[id] < r[p]) p = id;
}

void dfs(int id) {
  int t = id <= n;
  if (id <= n) dp[id][1] = 1;
  REP(i,0,child[id].size()) {
    int cid = child[id][i];
    dfs(cid);
    dp[id][0] += dp[cid][t];
    dp[id][1] += dp[cid][1 ^ t];
  }
  dp[id][1] = max(dp[id][0], dp[id][1]);
}

int main() {
  int q;
  cin >> n >> q;
  vector<VI> es;
  REP(i,1,n+q+1) {
    cin >> x[i] >> y[i] >> r[i];
    es.push_back(VI({r[i], x[i], y[i], i}));
  }
  sort(es.begin(), es.end());
  FILL(par, -1);
  VI roots;
  int esz = es.size();
  REP(ei,0,esz) {
    int id = es[ei][3];
    REP(ej,ei+1,min(esz,ei+IT_LIMIT+1)) {
      int jid = es[ej][3];
      if (contains(jid, id)) {
        update(par[id], jid);
        if (par[id] != -1) break;
      }
    }
    if (par[id] == -1) {
      REP(ej,max(esz-IT_LIMIT,ei+IT_LIMIT),esz) {
        int jid = es[ej][3];
        if (contains(jid, id)) {
          update(par[id], jid);
          if (par[id] != -1) break;
        }
      }
    }
    if (par[id] == -1) roots.push_back(id);
    else child[par[id]].push_back(id);
  }
  REP(i,0,roots.size()) dfs(roots[i]);
  REP(i,n+1,n+q+1) cout << max(dp[i][0] + 1, dp[i][1]) << endl;
  return 0;
}
